"""Eus group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.core.contrastive_pairs.lm_eval_pairs.lm_task_extractors."

EUS_TASKS = {
    "eus_exams": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_ejadministrativo": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_ejauxiliar": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_ejsubalterno": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_ejtecnico": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeayuntamientovitoria": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opebilbao": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeehuadmin": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeehuaux": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeehubiblio": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeehuderecho": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeehueconomicas": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeehuempresariales": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeehusubalterno": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeehutecnico": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeehutecnicob": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeosakiadmin": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeosakiaux": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeosakiauxenf": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeosakicelador": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeosakienf": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeosakijuridico": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeosakioperario": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeosakitecnico": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_opeosakivarios": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_osakidetza1c": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_osakidetza2c": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_osakidetza3c": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_osakidetza4c": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_osakidetza5c": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_osakidetza6c": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_osakidetza7c": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_osakidetza8c": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_es_osakidetza9c": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_ejadministrari": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_ejlaguntza": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_ejlaguntzaile": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_ejteknikari": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opebilbaoeu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeehuadmineu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeehuauxeu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeehubiblioeu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeehuderechoeu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeehueconomicaseu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeehuempresarialeseu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeehusubalternoeu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeehutecnicoeu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeehuteknikarib": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opegasteizkoudala": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeosakiadmineu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeosakiauxenfeu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeosakiauxeu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeosakiceladoreu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeosakienfeu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeosakioperarioeu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeosakitecnicoeu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_opeosakivarioseu": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_osakidetza1e": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_osakidetza2e": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_osakidetza3e": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_osakidetza5e": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_osakidetza6e": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_exams_eu_osakidetza7e": f"{BASE_IMPORT}eus_exams:EusExamsExtractor",
    "eus_proficiency": f"{BASE_IMPORT}eus_proficiency:EusProficiencyExtractor",
    "eus_reading": f"{BASE_IMPORT}eus_reading:EusReadingExtractor",
    "eus_trivia": f"{BASE_IMPORT}eus_trivia:EusTriviaExtractor",
}
